# Run this file:
# uv run pytest -s tests/test_injection_api.py
from pprint import pprint
from typing import Any, Dict, List
import pytest


@pytest.mark.parametrize("namespace, mode", [("ts", "display"), ("ts", "engine")])
def test_get_injection_conf(sdk, namespace: str, mode: str):
    """测试获取注入配置信息"""
    data = sdk.injection.get_conf(namespace, mode)
    pprint(data)


@pytest.mark.parametrize("page_num, page_size", [(1, 10), (0, 10)])
def test_list_injections(sdk, page_num: int, page_size: int):
    """测试分页查询注入记录"""
    data = sdk.injection.list(page_num, page_size)
    pprint(data)


@pytest.mark.parametrize(
    "benchmark, interval, pre_duration, specs",
    [
        # PodFailure-dev
        (
            "clickhouse",
            4,
            1,
            [
                {
                    "children": {
                        "1": {
                            "children": {
                                "0": {"value": 1},
                                "1": {"value": 0},
                                "2": {"value": 29},
                            }
                        },
                    },
                    "value": 1,
                },
                {
                    "children": {
                        "1": {
                            "children": {
                                "0": {"value": 1},
                                "1": {"value": 0},
                                "2": {"value": 42},
                            }
                        },
                    },
                    "value": 1,
                },
                {
                    "children": {
                        "1": {
                            "children": {
                                "0": {"value": 1},
                                "1": {"value": 0},
                                "2": {"value": 25},
                            }
                        },
                    },
                    "value": 1,
                },
                {
                    "children": {
                        "1": {
                            "children": {
                                "0": {"value": 1},
                                "1": {"value": 0},
                                "2": {"value": 13},
                            }
                        },
                    },
                    "value": 1,
                },
            ],
        ),
        # CPUStress-prod
        (
            "clickhouse",
            30,
            10,
            [
                {
                    "children": {
                        "4": {
                            "children": {
                                "0": {"value": 15},
                                "1": {"value": 0},
                                "2": {"value": 32},
                                "3": {"value": 10},
                                "4": {"value": 2},
                            }
                        },
                    },
                    "value": 4,
                },
            ],
        ),
        # JVMMemoryStress-dev
        (
            "clickhouse",
            3,
            1,
            [
                {
                    "children": {
                        "28": {
                            "children": {
                                "0": {"value": 1},
                                "1": {"value": 0},
                                "2": {"value": 611},
                                "3": {"value": 1},
                            }
                        },
                    },
                    "value": 28,
                },
            ],
        ),
        # NetworkDuplicate-dev
        (
            "clickhouse",
            3,
            1,
            [
                {
                    "children": {
                        "19": {
                            "children": {
                                "0": {"value": 1},
                                "1": {"value": 0},
                                "2": {"value": 43},
                                "3": {"value": 23},
                                "4": {"value": 14},
                                "5": {"value": 1},
                            }
                        },
                    },
                    "value": 19,
                },
            ],
        ),
        (
            "clickhouse",
            3,
            1,
            [
                {
                    "children": {
                        "1": {
                            "children": {
                                "0": {"value": 1},
                                "1": {"value": 0},
                                "2": {"value": 42},
                            }
                        },
                    },
                    "value": 1,
                },
                {
                    "children": {
                        "1": {
                            "children": {
                                "0": {"value": 1},
                                "1": {"value": 0},
                                "2": {"value": 35},
                            }
                        },
                    },
                    "value": 1,
                },
            ],
        ),
    ],
)
def test_submit_injections(
    sdk, benchmark: str, interval: int, pre_duration: int, specs: List[Dict[str, Any]]
):
    """测试批量注入故障"""
    data = sdk.injection.submit(benchmark, interval, pre_duration, specs)
    pprint(data)



# Run this file:
# uv run pytest -s tests/test_trace_api.py
from typing import Optional
from pprint import pprint
from rcabench.model.error import ModelHTTPError
import pytest


@pytest.mark.parametrize(
    "trace_id, last_event_id, timeout",
    [("8c3e4dd4-db86-49d9-b034-06e5a97c632c", "0", 600)],
)
def test_get_trace_events(
    sdk, trace_id: str, last_event_id: str, timeout: Optional[float]
):
    data = sdk.trace.get_trace_events(trace_id, last_event_id, timeout)
    if isinstance(data, ModelHTTPError):
        pytest.fail("Failed to get trace events")

    pprint(data)



from typing import List, Optional
from ..const import Evaluation
from pydantic import BaseModel, Field, field_validator


class EvaluationReq(BaseModel):
    """
    评估请求

    Attributes:
        execution_ids: 需要评估的执行ID列表
        metrics: 可选，要计算的评估指标
        rank: 可选，要计算的排名靠前的结果数量
    """

    execution_ids: List[int] = Field(
        ...,
        description="List of execution IDs to be evaluated",
        json_schema_extra={
            "example": [311],
        },
    )

    metrics: Optional[List[str]] = Field(
        None,
        description="Metrics to be calculated in the evaluation",
        json_schema_extra={
            "example": ["accuracy"],
        },
    )

    rank: Optional[int] = Field(
        None,
        description="Number of top results to be calculated",
        json_schema_extra={
            "example": 5,
        },
    )

    @field_validator("execution_ids")
    @classmethod
    def validate_execution_ids(cls, value: List[int]) -> List[int]:
        for id in value:
            if id <= 0:
                raise ValueError("Execution IDs must be positive integers")

        return value

    @field_validator("rank")
    @classmethod
    def validate_rank(cls, value: int) -> int:
        if value is not None and value not in Evaluation.ALLOWED_RANKS:
            raise ValueError(
                f"Invalid rank value. Must be one of: {', '.join(str(r) for r in Evaluation.ALLOWED_RANKS)}"
            )

        return value



# coding: utf-8

"""
    RCABench API

    RCABench - A comprehensive root cause analysis benchmarking platform for microservices This API provides endpoints for managing datasets, algorithms, evaluations, and fault injections for root cause analysis in distributed systems and microservices architectures.

    The version of the OpenAPI document: 1.0.1
    Contact: team@rcabench.com
    Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from rcabench.openapi.models.dto_generic_response_array_dto_raw_data_item import DtoGenericResponseArrayDtoRawDataItem
from rcabench.openapi.models.dto_generic_response_dto_evaluation_list_resp import DtoGenericResponseDtoEvaluationListResp

from rcabench.openapi.api_client import ApiClient, RequestSerialized
from rcabench.openapi.api_response import ApiResponse
from rcabench.openapi.rest import RESTResponseType


class EvaluationApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://rcabench.openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def api_v1_evaluations_get(
        self,
        execution_ids: Annotated[Optional[List[StrictInt]], Field(description="执行结果 ID 数组")] = None,
        algorithms: Annotated[Optional[List[StrictStr]], Field(description="算法名称数组")] = None,
        levels: Annotated[Optional[List[StrictStr]], Field(description="级别名称数组")] = None,
        metrics: Annotated[Optional[List[StrictStr]], Field(description="指标名称数组")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DtoGenericResponseDtoEvaluationListResp:
        """获取每种算法的执行历史记录

        返回每种算法的执行历史记录

        :param execution_ids: 执行结果 ID 数组
        :type execution_ids: List[int]
        :param algorithms: 算法名称数组
        :type algorithms: List[str]
        :param levels: 级别名称数组
        :type levels: List[str]
        :param metrics: 指标名称数组
        :type metrics: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_evaluations_get_serialize(
            execution_ids=execution_ids,
            algorithms=algorithms,
            levels=levels,
            metrics=metrics,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseDtoEvaluationListResp",
            '400': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_evaluations_get_with_http_info(
        self,
        execution_ids: Annotated[Optional[List[StrictInt]], Field(description="执行结果 ID 数组")] = None,
        algorithms: Annotated[Optional[List[StrictStr]], Field(description="算法名称数组")] = None,
        levels: Annotated[Optional[List[StrictStr]], Field(description="级别名称数组")] = None,
        metrics: Annotated[Optional[List[StrictStr]], Field(description="指标名称数组")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DtoGenericResponseDtoEvaluationListResp]:
        """获取每种算法的执行历史记录

        返回每种算法的执行历史记录

        :param execution_ids: 执行结果 ID 数组
        :type execution_ids: List[int]
        :param algorithms: 算法名称数组
        :type algorithms: List[str]
        :param levels: 级别名称数组
        :type levels: List[str]
        :param metrics: 指标名称数组
        :type metrics: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_evaluations_get_serialize(
            execution_ids=execution_ids,
            algorithms=algorithms,
            levels=levels,
            metrics=metrics,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseDtoEvaluationListResp",
            '400': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_evaluations_get_without_preload_content(
        self,
        execution_ids: Annotated[Optional[List[StrictInt]], Field(description="执行结果 ID 数组")] = None,
        algorithms: Annotated[Optional[List[StrictStr]], Field(description="算法名称数组")] = None,
        levels: Annotated[Optional[List[StrictStr]], Field(description="级别名称数组")] = None,
        metrics: Annotated[Optional[List[StrictStr]], Field(description="指标名称数组")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """获取每种算法的执行历史记录

        返回每种算法的执行历史记录

        :param execution_ids: 执行结果 ID 数组
        :type execution_ids: List[int]
        :param algorithms: 算法名称数组
        :type algorithms: List[str]
        :param levels: 级别名称数组
        :type levels: List[str]
        :param metrics: 指标名称数组
        :type metrics: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_evaluations_get_serialize(
            execution_ids=execution_ids,
            algorithms=algorithms,
            levels=levels,
            metrics=metrics,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseDtoEvaluationListResp",
            '400': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_evaluations_get_serialize(
        self,
        execution_ids,
        algorithms,
        levels,
        metrics,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'execution_ids': 'csv',
            'algorithms': 'csv',
            'levels': 'csv',
            'metrics': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if execution_ids is not None:
            
            _query_params.append(('execution_ids', execution_ids))
            
        if algorithms is not None:
            
            _query_params.append(('algorithms', algorithms))
            
        if levels is not None:
            
            _query_params.append(('levels', levels))
            
        if metrics is not None:
            
            _query_params.append(('metrics', metrics))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/evaluations',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_evaluations_raw_data_get(
        self,
        algorithms: Annotated[List[StrictStr], Field(description="算法数组")],
        datasets: Annotated[List[StrictStr], Field(description="数据集数组")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DtoGenericResponseArrayDtoRawDataItem:
        """获取原始评估数据

        根据算法和数据集的笛卡尔积获取对应的原始评估数据，包括粒度记录和真实值信息

        :param algorithms: 算法数组 (required)
        :type algorithms: List[str]
        :param datasets: 数据集数组 (required)
        :type datasets: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_evaluations_raw_data_get_serialize(
            algorithms=algorithms,
            datasets=datasets,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseArrayDtoRawDataItem",
            '400': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_evaluations_raw_data_get_with_http_info(
        self,
        algorithms: Annotated[List[StrictStr], Field(description="算法数组")],
        datasets: Annotated[List[StrictStr], Field(description="数据集数组")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DtoGenericResponseArrayDtoRawDataItem]:
        """获取原始评估数据

        根据算法和数据集的笛卡尔积获取对应的原始评估数据，包括粒度记录和真实值信息

        :param algorithms: 算法数组 (required)
        :type algorithms: List[str]
        :param datasets: 数据集数组 (required)
        :type datasets: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_evaluations_raw_data_get_serialize(
            algorithms=algorithms,
            datasets=datasets,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseArrayDtoRawDataItem",
            '400': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_evaluations_raw_data_get_without_preload_content(
        self,
        algorithms: Annotated[List[StrictStr], Field(description="算法数组")],
        datasets: Annotated[List[StrictStr], Field(description="数据集数组")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """获取原始评估数据

        根据算法和数据集的笛卡尔积获取对应的原始评估数据，包括粒度记录和真实值信息

        :param algorithms: 算法数组 (required)
        :type algorithms: List[str]
        :param datasets: 数据集数组 (required)
        :type datasets: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_evaluations_raw_data_get_serialize(
            algorithms=algorithms,
            datasets=datasets,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseArrayDtoRawDataItem",
            '400': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_evaluations_raw_data_get_serialize(
        self,
        algorithms,
        datasets,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'algorithms': 'csv',
            'datasets': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if algorithms is not None:
            
            _query_params.append(('algorithms', algorithms))
            
        if datasets is not None:
            
            _query_params.append(('datasets', datasets))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/evaluations/raw-data',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





from rcabench.openapi.api_client import ApiClient, Configuration
from rcabench.openapi import TraceApi, InjectionApi, TaskApi
from rcabench.model.trace import StreamEvent
from rcabench.rcabench import RCABenchSDK
import typer
import json
from rich.console import Console
from rich.json import JSON
from typing import Any

app = typer.Typer(pretty_exceptions_show_locals=False)
console = Console()


def print_json_highlighted(data: Any) -> None:
    if isinstance(data, str):
        json_str = data
    else:
        json_str = json.dumps(data, indent=2, ensure_ascii=False, default=str)

    json_obj = JSON(json_str)
    console.print(json_obj)


@app.command()
def ns_stat(
    host: str = "http://10.10.10.220:32080",
) -> None:
    """get namespace lock status"""
    configuration: Configuration = Configuration(host=host)

    with ApiClient(configuration=configuration) as client:
        api: InjectionApi = InjectionApi(client)
        resp = api.api_v1_injections_ns_status_get()
        print_json_highlighted(resp.data)


@app.command()
def task_queue(
    host: str = "http://10.10.10.220:32080",
) -> None:
    """get task queue status"""
    configuration: Configuration = Configuration(host=host)

    with ApiClient(configuration=configuration) as client:
        api: TaskApi = TaskApi(client)
        resp = api.api_v1_tasks_queue_get()
        data = resp.data
        assert data is not None, "No data returned from task queue"
        if hasattr(data, "model_dump"):
            print_json_highlighted(data.model_dump())
        else:
            print_json_highlighted(data)


@app.command()
def trace_stat(
    host: str = "http://10.10.10.220:32080",
    lookback: str = "1h",
) -> None:
    """get trace analysis information"""
    configuration: Configuration = Configuration(host=host)

    with ApiClient(configuration=configuration) as client:
        api: TraceApi = TraceApi(client)
        resp = api.api_v1_traces_analyze_get(lookback=lookback)
        data = resp.data
        assert data is not None, "No data returned from task queue"
        print_json_highlighted(data)


@app.command()
def trace_stream(
    trace_id: str,
    host: str = "http://10.10.10.220:32080",
    timeout: float = 600000,
) -> None:
    """get one trace stream event by trace_id"""
    sdk = RCABenchSDK(host)
    for e in sdk.trace.stream_trace_events(trace_id, timeout=timeout):
        assert isinstance(e, StreamEvent)
        assert isinstance(e.payload, str)
        e.payload = json.loads(e.payload)
        print_json_highlighted(e.model_dump())


if __name__ == "__main__":
    app()
